@@ -147,3 +147,19 @@ func TestStripDirectives(t *testing.T) {
 		Update:  *updateFlag,
 	}.Run(t)
 }
+
+func TestGitLabOutput(t *testing.T) {
+	TestCase{
+		Dir:     "gitlab_output",
+		Command: yamlfmtWithArgs("-dry -output_format gitlab ."),
+		Update:  *updateFlag,
+	}.Run(t)
+}
+
+func TestPatternFile(t *testing.T) {
+	TestCase{
+		Dir:     "pattern_file",
+		Command: yamlfmtWithArgs("-match_type gitignore yamlfmt.patterns"),
+		Update:  *updateFlag,
+	}.Run(t)
+}
